Naguine
=======
[![Build Status](https://travis-ci.org/colexyz/django-naguine.svg?branch=master)](https://travis-ci.org/colexyz/django-naguine)
[![codecov](https://codecov.io/gh/colexyz/django-naguine/branch/master/graph/badge.svg)](https://codecov.io/gh/colexyz/django-naguine)

Django Web Framework's sidekick, Sophie "Naguine" Ziegler.


Requirements
============
- Python: 3.6
- Django: 2.0, 2.1


Install
=======
`pip install django-naguine`

and add `naguine` to your project's `INSTALLED_APPS`:
```
INSTALLED_APPS = [
    ...
    'naguine',
]
```
